@@ -54,7 +54,7 @@ except ImportError:
     MAX_FONT_SIZE = 69
 
 
-__version__ = '0.1.11'
+__version__ = '0.1.12'
 
 
 class AutoFontSizeBehavior:
@@ -130,6 +130,9 @@ class AutoFontSizeBehavior:
 
     def _start_font_anim(self, *_args):
         """ delayed anim check """
+        if getattr(self, '_ticker_text_updating', False):
+            return                  # ignore when SimpleAutoTickerBehaviour is shortening text
+
         self._stop_font_anim()      # stop just running animation (obsoleted by this new text/size change)
         self.texture_update()
         if not self.texture_size[0]:
@@ -406,9 +409,9 @@ class SimpleAutoTickerBehavior:
             self._start_length_anim()
 
     def _start_length_anim(self, *_args):
+        self.text = self._ori_text
         self._stop_offset_anim()
         self._stop_length_anim()
-        self.text = self._ori_text
 
         self._ticker_texture_width = self.width - self.auto_ticker_text_spacing
 
@@ -425,16 +428,14 @@ class SimpleAutoTickerBehavior:
         if self._length_anim:
             self._length_anim.stop(self)
             self._length_anim = None
-
-            self._ticker_text_length = len(self._ori_text)
-            self._ticker_texture_width = 0.0
+        self._ticker_text_length = len(self._ori_text)
+        self._ticker_texture_width = 0.0
 
     def _stop_offset_anim(self):
         if self._offset_anim:
             self._offset_anim.stop(self)
             self._offset_anim = None
-
-            self._ticker_text_offset = 0
+        self._ticker_text_offset = 0
 
     def _ticker_length_progress(self, _anim: Animation, _self: Widget, _progress: float):
         self.texture_update()
@@ -443,7 +444,7 @@ class SimpleAutoTickerBehavior:
             self._ticker_text_offset = round(self._ticker_max_offset() / 2)
             if self._length_anim:
                 self._length_anim.stop(self)
-
+                self._length_anim = None
             self._start_offset_anim()
         else:
             self._ticker_text_update(self.text[1:-1])
@@ -457,7 +458,7 @@ class SimpleAutoTickerBehavior:
         self._ticker_text_update(self._ori_text[beg:end])
         if progress >= 1.0 and self._offset_anim:      # added `and self._offset_anim` for mypy
             self._offset_anim.stop(self)
-            self._offset_anim = Animation(_ticker_text_offset=0 if beg else self._ticker_max_offset(),
+            self._offset_anim = Animation(_ticker_text_offset=0 if beg else self._ticker_max_offset() + 1,
                                           d=self.auto_ticker_offset_anim_duration)
             self._offset_anim.bind(on_progress=self._ticker_offset_progress)
             self._offset_anim.start(self)
